@@ -40,11 +40,8 @@ dls = DLStudio(
                   momentum = 0.9,
                   learning_rate = 1e-4,
                   epochs = 6,
-#                  epochs = 1,
                   batch_size = 4,
                   classes = ('rectangle','triangle','disk','oval','star'),
-                  debug_train = 1,
-                  debug_test = 1,
                   use_gpu = True,
               )
 
@@ -53,13 +50,11 @@ segmenter = DLStudio.SemanticSegmentation( dl_studio = dls )
 dataserver_train = DLStudio.SemanticSegmentation.PurdueShapes5MultiObjectDataset(
                           train_or_test = 'train',
                           dl_studio = dls,
-#                          dataset_file = "PurdueShapes5MultiObject-20-train.gz", 
                           dataset_file = "PurdueShapes5MultiObject-10000-train.gz", 
                         )
 dataserver_test = DLStudio.SemanticSegmentation.PurdueShapes5MultiObjectDataset(
                           train_or_test = 'test',
                           dl_studio = dls,
-#                          dataset_file = "PurdueShapes5MultiObject-20-test.gz"
                           dataset_file = "PurdueShapes5MultiObject-1000-test.gz"
                         )
 segmenter.dataserver_train = dataserver_train
@@ -71,10 +66,10 @@ model = segmenter.mUnet(skip_connections=True, depth=16)
 #model = segmenter.mUnet(skip_connections=False, depth=4)
 
 number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requires_grad)
-print("\n\nThe number of learnable parameters in the model: %d\n\n" % number_of_learnable_params)
+print("\n\nThe number of learnable parameters in the model: %d\n" % number_of_learnable_params)
 
 num_layers = len(list(model.parameters()))
-print("\n\nThe number of layers in the model: %d\n\n" % num_layers)
+print("\nThe number of layers in the model: %d\n\n" % num_layers)
 
 
 segmenter.run_code_for_training_for_semantic_segmentation(model)
